import json
import yaml


def to_yaml_str(json_obj):
    yaml_obj = yaml.load(json.dumps(json_obj), Loader=yaml.SafeLoader)
    return yaml.dump(yaml_obj, default_flow_style=False)


def fmt_output(json_output, json_obj):
    if json_output:
        return json.dumps(json_obj)
    else:
        return to_yaml_str(json_obj)



import click
import mijn_simpel
from mijn_simpel.client import Session, Subscription
from mijn_simpel.utils import fmt_output
from os.path import expanduser

@click.group()
@click.option('--cookie-jar', default=expanduser("~") + '/.config/mijn-simpel-cookie',
              show_default='~/.config/mijn-simpel-cookie',
              help='Cookie jar for session storing.', envvar='MIJN_SIMPEL_COOKIE_JAR')
@click.option('--json/--no-json', default=False,
              help='Output in JSON', envvar='MIJN_SIMPEL_JSON_OUTPUT')
def main(cookie_jar, json):
    global json_output
    json_output = json
    global s
    s = Session(cookie_jar)
    pass

@main.command(help='Login to service.')
@click.option('--username', prompt='Mijn Simpel username',
              help='Username on mijn.simpel.nl.', envvar='MIJN_SIMPEL_USERNAME')
@click.password_option(envvar='MIJN_SIMPEL_PASSWORD',
                       help='Password on mijn.simpel.nl.')
def login(username, password):
    resp = s.login(username, password)
    if resp:
        click.echo('Logged in')

@main.command(help='List subscriptions.')
def subscriptions():
    resp = s.account_subscription_overview()
    if resp:
        click.echo(fmt_output(json_output, resp))

@main.group(help="Information for subscription.")
@click.argument('subscription-id',
              envvar='MIJN_SIMPEL_SUBSCRIPTION_ID')
def subscription(subscription_id):
    global subscription
    subscription = s.subscription(subscription_id)
    pass
        
@subscription.command(help='Show dashboard.')
def dashboard():
    resp = subscription.dashboard()
    if resp:
        click.echo(fmt_output(json_output, resp))

@subscription.command(help='Show products.')
def products():
    resp = subscription.products()
    if resp:
        click.echo(fmt_output(json_output, resp))

@subscription.command(help='Show ceiling.')
def ceiling():
    resp = subscription.ceiling()
    if resp:
        click.echo(fmt_output(json_output, resp))

@subscription.command(help='Show latest invoice.')
def latest_invoice():
    resp = subscription.latest_invoice()
    if resp:
        click.echo(fmt_output(json_output, resp))

@subscription.command(help='Show correction for billing period.')
def correction_for_billing_period():
    resp = subscription.correction_for_billing_period()
    if resp:
        click.echo(fmt_output(json_output, resp))

@subscription.command(help='Show usage summary.')
def usage_summary():
    resp = subscription.usage_summary()
    if resp:
        click.echo(fmt_output(json_output, resp))

@subscription.command(help='Show other costs.')
def other_costs():
    resp = subscription.usage_other_costs()
    if resp:
        click.echo(fmt_output(json_output, resp))

@subscription.command(help='Show cdrs.')
def cdrs():
    resp = subscription.usage_cdrs()
    if resp:
        click.echo(fmt_output(json_output, resp))


if __name__ == '__main__':
    main()



import requests
import http.cookiejar
from pathlib import Path
import os, stat


class ApiError(Exception):
    """An API Error Exception"""

    def __init__(self, resp):
        self.resp = resp

    def __str__(self):
        return "ApiError: {}".format(vars(self.resp))

    
class Session():

    def __init__(self, cookie_path):
        self.s = requests.Session()
        Path(cookie_path).parent.mkdir(parents=True, exist_ok=True)
        self.s.cookies = http.cookiejar.LWPCookieJar(cookie_path)
        try:
            self.s.cookies.load(ignore_discard=True, ignore_expires=True)
        except FileNotFoundError:
            pass

    def _url(path):
        return 'https://api.simpel.nl/' + path

    def close(self):
        self.s.close()

    def save(self):
        self.s.cookies.save(ignore_discard=True, ignore_expires=True)
        os.chmod(self.s.cookies.filename, stat.S_IREAD | stat.S_IWRITE)

    def login(self, username, password):
        resp = self.s.post(Session._url('login'), json={
            "username": username,
            "password": password,
            "remember": True
        })
        if resp.status_code != 200:
            raise ApiError(resp)
        else:
            self.save()
            return True

    def account_subscription_overview(self):
        resp = self.s.get(Session._url('account/subscription-overview'))
        if resp.status_code != 200:
            raise ApiError(resp)
        else:
            self.save()
            return resp.json()

    def subscription(self, subscription_id):
        return Subscription(self, subscription_id)

class Subscription():

    def __init__(self, session, sid):
        self.s = session
        self.sid = sid

    def _url(path):
        return 'https://mijn.simpel.nl/api/' + path

    def get(self, path):
        resp = self.s.s.get(Subscription._url(path), params={
            "sid": self.sid
        })
        if resp.status_code != 200:
            raise ApiError(resp)
        else:
            self.s.save()
            return resp.json()            
        
    def dashboard(self):
        return self.get('dashboard')

    def products(self):
        return self.get('subscription/products')

    def ceiling(self):
        return self.get('subscription/ceiling')

    def usage_summary(self):
        return self.get('usage/usage-summary')

    def usage_other_costs(self):
        return self.get('usage/other-costs')

    def usage_cdrs(self):
        return self.get('usage/cdrs')

    def latest_invoice(self):
        return self.get('invoice/latest')

    def correction_for_billing_period(self):
        return self.get('correction/for-billing-period')



#!/usr/bin/env python

from setuptools import setup

REQUIRES = []
def read_requirements(file):
    with open(file) as f:
        for line in f:
            line, _, _ = line.partition('#')
            line = line.strip()
            if ';' in line:
                requirement, _, specifier = line.partition(';')
                for_specifier = EXTRAS.setdefault(':{}'.format(specifier), [])
                for_specifier.append(requirement)
            else:
                REQUIRES.append(line)

try:
    read_requirements('requirements.txt')
except FileNotFoundError:
    read_requirements('MijnSimpel.egg-info/requires.txt')

with open("README.rst", "r") as fh:
    long_description = fh.read()

setup(name='MijnSimpel',
      version='0.6',
      license='MIT',
      description='Python Client to Mijn Simpel',
      long_description=long_description,
      long_description_content_type="text/x-rst",
      author='Aleksandr Vinokurov',
      author_email="aleksandr.vin@gmail.com",
      url='https://github.com/aleksandr-vin/mijn-simpel-python-client',
      download_url = 'https://github.com/aleksandr-vin/mijn-simpel-python-client/archive/v0.5.tar.gz',
      keywords = ['scraping', 'mijn-simpel', 'telecom', 'usage', 'cli', 'client', 'simpel', 'nl'],
      packages=['mijn_simpel'],
      install_requires=REQUIRES,
      entry_points = {
        'console_scripts': ['mijn-simpel=mijn_simpel.cli:main'],
      },
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Intended Audience :: Customer Service',
          'Intended Audience :: End Users/Desktop',
          'Intended Audience :: Information Technology',
          'Intended Audience :: Telecommunications Industry',
          'Topic :: Software Development',
          'Topic :: Communications :: Telephony',
          'Topic :: Home Automation',
          'Topic :: Internet',
          'Topic :: Scientific/Engineering :: Information Analysis',
          'Topic :: Software Development :: Libraries',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: Software Development :: User Interfaces',
          'Topic :: System :: Monitoring',
          'Natural Language :: Dutch',
          'Natural Language :: English',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3',
      ],
)
